@@ -1,30 +1,52 @@
 OC.L10N.register(
     "calendar",
     {
+    "Hello," : "Вітаем,",
+    "Upcoming events" : "Будучыя падзеі",
+    "No upcoming events" : "Няма будучых падзей",
+    "%1$s with %2$s" : "%1$s з %2$s",
     "Calendar" : "Каляндар",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Confirm" : "Пацвердзіць",
     "Description:" : "Апісанне:",
     "Date:" : "Дата:",
+    "You will receive a link with the confirmation email" : "Вы атрымаеце спасылку з пацвярджэннем па электроннай пошце",
     "Where:" : "Дзе:",
+    "Comment:" : "Каментарый:",
     "Location:" : "Месцазнаходжанне:",
     "Duration:" : "Працягласць:",
+    "%1$s from %2$s to %3$s" : "%1$s з %2$s да %3$s",
     "Dates:" : "Даты:",
+    "Respond" : "Адказаць",
+    "A Calendar app for Nextcloud" : "Праграма Каляндар для Nextcloud",
     "Next week" : "На наступным тыдні",
     "Event" : "Падзея",
     "Today" : "Сёння",
     "Year" : "Год",
+    "List" : "Спіс",
+    "Appointment link was copied to clipboard" : "Спасылка на сустрэчу скапіявана ў буфер абмену",
+    "Appointment link could not be copied to clipboard" : "Не ўдалося скапіяваць спасылку на сустрэчу ў буфер абмену",
     "Preview" : "Перадпрагляд",
     "Copy link" : "Скапіяваць спасылку",
     "Edit" : "Рэдагаваць",
     "Delete" : "Выдаліць",
+    "Appointment schedules" : "Расклад сустрэч",
+    "Create new" : "Стварыць новую",
+    "Disable calendar \"{calendar}\"" : "Адключыць каляндар \"{calendar}\"",
+    "Disable untitled calendar" : "Адключыць каляндар без назвы",
+    "Enable calendar \"{calendar}\"" : "Уключыць каляндар \"{calendar}\"",
+    "Enable untitled calendar" : "Уключыць каляндар без назвы",
     "Untitled calendar" : "Каляндар без назвы",
+    "Edit calendar" : "Рэдагаваць каляндар",
     "Calendars" : "Календары",
     "New calendar with task list" : "Новы каляндар са спісам заданняў",
     "Export" : "Экспарт",
+    "Trash bin" : "Сметніца",
     "Name" : "Назва",
     "Deleted" : "Выдалены",
     "Restore" : "Аднавіць",
     "Delete permanently" : "Выдаліць назаўжды",
+    "Shared calendars" : "Абагуленыя календары",
     "Share link" : "Абагуліць спасылку",
     "Copy public link" : "Скапіяваць публічную спасылку",
     "Unshare with {displayName}" : "Скасаваць абагульванне з {displayName}",
@@ -65,6 +87,7 @@ OC.L10N.register(
     "Sunday" : "Нядзеля",
     "Your name" : "Ваша імя",
     "Back" : "Назад",
+    "Successfully added Talk conversation link to description." : "Спасылка на размову ў Talk паспяхова дададзена ў апісанне.",
     "Select conversation" : "Выберыце размову",
     "on" : "укл.",
     "Notification" : "Апавяшчэнне",
@@ -87,6 +110,7 @@ OC.L10N.register(
     "Accept" : "Прыняць",
     "Decline" : "Адхіліць",
     "No attendees yet" : "Пакуль няма ўдзельнікаў",
+    "Successfully appended link to talk room to description." : "Спасылка на пакой у Talk паспяхова дададзена ў апісанне.",
     "Attendees" : "Удзельнікі",
     "Remove group" : "Выдаліць групу",
     "Remove attendee" : "Выдаліць удзельніка",
@@ -101,20 +125,24 @@ OC.L10N.register(
     "Remove participant" : "Выдаліць удзельніка",
     "Yes" : "Так",
     "No" : "Не",
+    "Maybe" : "Магчыма",
     "None" : "Няма",
     "Create" : "Ствараць",
     "from {formattedDate} at {formattedTime}" : "ад {formattedDate} да {formattedTime}",
     "Global" : "Глабальны",
     "Public calendars" : "Публічныя календары",
+    "Time:" : "Час:",
     "Personal" : "Асабістыя",
     "Show unscheduled tasks" : "Паказаць незапланаваныя заданні",
     "Unscheduled tasks" : "Незапланаваныя заданні",
     "Availability of {displayName}" : "Даступнасць {displayName}",
+    "All day" : "Увесь дзень",
     "Invite" : "Запрасіць",
     "Discard changes?" : "Адхіліць змены?",
     "Untitled event" : "Падзея без назвы",
     "Close" : "Закрыць",
     "Selected" : "Выбрана",
+    "No Description" : "Няма апісання",
     "Title" : "Загаловак",
     "15 min" : "15 хв",
     "30 min" : "30 хв",
@@ -137,12 +165,15 @@ OC.L10N.register(
     "%n more" : "%n яшчэ",
     "_+%n more_::_+%n more_" : ["+%n яшчэ","+%n яшчэ","+%n яшчэ","+%n яшчэ"],
     "Other" : "Іншае",
+    "Add a location" : "Дадайце месцазнаходжанне",
+    "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Дадайце апісанне\n\n- Пра што гэтая сустрэча\n- Пункты парадку дня\n- Што трэба падрыхтаваць удзельнікам",
     "Status" : "Статус",
     "Confirmed" : "Пацверджана",
     "Canceled" : "Скасавана",
     "Categories" : "Катэгорыі",
     "Error while sharing file" : "Памылка пры абагульванні файла",
     "User not found" : "Карыстальнік не знойдзены",
+    "Calendar name …" : "Назва календара …",
     "Show keyboard shortcuts" : "Паказаць спалучэнні клавіш"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
