@@ -31,7 +31,6 @@ OC.L10N.register(
     "Restore" : "Restaurar",
     "Delete permanently" : "Borrar permanentemente",
     "Deck" : "Deck",
-    "Hidden" : "Oculto",
     "Share link" : "Compartir enlace",
     "can edit" : "puede editar",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
@@ -77,6 +76,7 @@ OC.L10N.register(
     "after" : "después",
     "Resources" : "Recursos",
     "available" : "disponible",
+    "None" : "Ninguno",
     "Global" : "Global",
     "Subscribe" : "Suscribir",
     "Personal" : "Personal",
@@ -97,6 +97,7 @@ OC.L10N.register(
     "Status" : "Estatus",
     "Confirmed" : "Confirmado",
     "Categories" : "Categorías",
-    "User not found" : "No se encontró el usuario"
+    "User not found" : "No se encontró el usuario",
+    "Hidden" : "Oculto"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
