@@ -169,6 +169,7 @@ OC.L10N.register(
     "Pick" : "Valitse",
     "Invalid location selected" : "Virheellinen sijainti valittu",
     "Attachments folder successfully saved." : "Liitteiden kansio tallennettu.",
+    "Error on saving attachments folder." : "Virhe liitetiedostokansiota tallennettaessa.",
     "Default attachments location" : "Liitteiden oletussijainti",
     "{filename} could not be parsed" : "Tiedostoa {filename} ei voitu jäsentää",
     "No valid files found, aborting import" : "Kelvollisia tiedostoja ei löytynyt, lopetetaan tuonti",
@@ -266,6 +267,7 @@ OC.L10N.register(
     "Could not book the appointment. Please try again later or contact the organizer." : "Tapaamista ei voitu kirjata. Ole hyvä ja yritä myöhemmin uudelleen tai ota yhteyttä järjestäjään.",
     "Back" : "Takaisin",
     "Book appointment" : "Varaa tapaaminen",
+    "Error fetching Talk conversations." : "Virhe noudettaessa Talk-keskusteluja.",
     "Conversation does not have a valid URL." : "Keskustelulla ei ole kelvollista URL-osoitetta.",
     "Successfully added Talk conversation link to location." : "Talk-keskustelulinkki lisätty sijaintiin.",
     "Successfully added Talk conversation link to description." : "Talk-keskustelulinkki lisätty kuvaukseen.",
@@ -374,8 +376,8 @@ OC.L10N.register(
     "Remove color" : "Poista väri",
     "Event title" : "Tapahtuman otsikko",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Koko päivän tapahtumia, jotka ovat osa toistuvaa tapahtumaa, ei voida muokata.",
-    "From" : "Lähettäjä",
-    "To" : "Vastaanottaja",
+    "From" : "Alkaen",
+    "To" : "Päättyen",
     "Repeat" : "Toista",
     "_time_::_times_" : ["kerran","kertaa"],
     "never" : "ei koskaan",
