@@ -108,7 +108,6 @@ OC.L10N.register(
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Item dalam keranjang sampah dihapus setelah {numDays} hari"],
     "Could not update calendar order." : "Tidak dapat membarui urutan kalender.",
     "Deck" : "Longgok",
-    "Hidden" : "Sembunyi",
     "An error occurred, unable to publish calendar." : "Terjadi galat, tidak dapat menerbitkan kalender.",
     "An error occurred, unable to send email." : "Terjadi galat, tidak dapat mengirim email.",
     "Embed code copied to clipboard." : "Kode tersemat disalin ke papan klip",
@@ -142,7 +141,7 @@ OC.L10N.register(
     "No valid files found, aborting import" : "Berkas valid tidak ditemukan, impor dibatalkan",
     "Import partially failed. Imported {accepted} out of {total}." : "Sebagian impor gagal. Dari {total} hanya {accepted} berhasil impor.",
     "Automatic" : "Otomatis",
-    "Automatic ({detected})" : "Otomatis ({detected})",
+    "Automatic ({timezone})" : "Otomatis ({timezone})",
     "New setting was not saved successfully." : "Setelan baru tidak berhasil tersimpan.",
     "Navigation" : "Navigasi",
     "Previous period" : "Periode sebelum",
@@ -259,6 +258,7 @@ OC.L10N.register(
     "Resources" : "Sumber daya",
     "Public calendar does not exist" : "Kalender publik tidak eksis",
     "Maybe the share was deleted or has expired?" : "Mungkin yang dibagikan terhapus atau kadaluwarsa?",
+    "None" : "Tidak ada",
     "Create" : "Buat",
     "on {formattedDate}" : "dalam {formattedDate}",
     "Please enter a valid date" : "Silakan isi tanggal valid",
@@ -344,6 +344,8 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
     "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
     "This is an event reminder." : "Ini adalah pengingat acara.",
+    "Hidden" : "Sembunyi",
+    "Automatic ({detected})" : "Otomatis ({detected})",
     "Shortcut overview" : "Ikhtisar pintasan",
     "Enable simplified editor" : "Aktifkan editor serderhana",
     "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci"
