@@ -21,6 +21,7 @@ OC.L10N.register(
     "can edit" : "អាច​កែប្រែ",
     "Save" : "រក្សាទុក",
     "Cancel" : "បោះបង់",
+    "General" : "ទូទៅ",
     "Update" : "ធ្វើ​បច្ចុប្បន្នភាព",
     "Location" : "ទីតាំង",
     "Description" : "ការ​អធិប្បាយ",
@@ -39,9 +40,13 @@ OC.L10N.register(
     "Repeat" : "ធ្វើម្ដងទៀត",
     "never" : "មិនដែរ",
     "first" : "ទីមួយ",
+    "Yes" : "បាទ ឬចាស",
+    "No" : "ទេ",
+    "None" : "គ្មាន",
     "Personal" : "ផ្ទាល់​ខ្លួន",
     "Edit event" : "កែ​ព្រឹត្តិការណ៍",
     "Close" : "បិទ",
+    "30 min" : "30 នាទី",
     "Daily" : "រាល់ថ្ងៃ",
     "Weekly" : "រាល់​សប្ដាហ៍",
     "second" : "ទីពីរ",
