@@ -122,7 +122,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Неможе да се ажурира редоследот на календарите.",
     "Shared calendars" : "Споделени календари",
     "Deck" : "Deck",
-    "Hidden" : "Сокриен",
     "Internal link" : "Внатрешен линк",
     "A private link that can be used with external clients" : "Приватен линк што може да се користи со надворешни клиенти",
     "Copy internal link" : "Копирај внатрешен линк",
@@ -150,7 +149,7 @@ OC.L10N.register(
     "Share with users or groups" : "Сподели со корисници или групи",
     "No users or groups" : "Нема корисници или групи",
     "Failed to save calendar name and color" : "Неуспешно зачувување на име на календар и боја",
-    "Calendar name …" : "Име на календар ...",
+    "Calendar name …" : "Име на календар …",
     "Never show me as busy (set this calendar to transparent)" : "Никогаш не ме прикажувај зафатен (постави го овој календар транспарентен)",
     "Share calendar" : "Сподели календар",
     "Unshare from me" : "Не споделувај со мене",
@@ -182,6 +181,7 @@ OC.L10N.register(
     "Automatic" : "Автоматски",
     "Automatic ({timezone})" : "Автоматски ({timezone})",
     "New setting was not saved successfully." : "Неуспешно зачувување на промените.",
+    "Timezone" : "Временска зона",
     "Navigation" : "Навигација",
     "Previous period" : "Предходен период",
     "Next period" : "Следен период",
@@ -210,6 +210,7 @@ OC.L10N.register(
     "Personal availability settings" : "Параметри за лична достапност",
     "Copy primary CalDAV address" : "Копирај примарна CalDAV адреса",
     "Copy iOS/macOS CalDAV address" : "Копирај iOS/macOS CalDAV адреса",
+    "View options" : "Прегледај опции ",
     "Enable birthday calendar" : "Овозможи календар со родендени",
     "Show tasks in calendar" : "Прикажи ги задачите во календарнот",
     "Show weekends" : "Прикажи викенди",
@@ -425,6 +426,7 @@ OC.L10N.register(
     "Yes" : "Да",
     "No" : "Не",
     "Maybe" : "Можеби",
+    "None" : "Ништо",
     "Create" : "Креирај",
     "from {formattedDate}" : "од {formattedDate}",
     "to {formattedDate}" : "до {formattedDate}",
@@ -611,6 +613,8 @@ OC.L10N.register(
     "This is an event reminder." : "Ова е потсетник за настан.",
     "Appointment not found" : "Терминот не е пронајден",
     "User not found" : "Корисникот не е пронајден",
+    "Hidden" : "Сокриен",
+    "Calendar name …" : "Име на календар ...",
     "Automatic ({detected})" : "Автоматски ({detected})",
     "Shortcut overview" : "Преглед на кратенки преку тастатура",
     "Enable simplified editor" : "Овозможи поедноставен уредувач",
