@@ -2,6 +2,7 @@ OC.L10N.register(
     "calendar",
     {
     "Cheers!" : "U zdravlje!",
+    "Location:" : "Lokacija:",
     "Today" : "Today",
     "Preview" : "Pregled",
     "Copy link" : "Kopiraj vezu",
@@ -31,11 +32,14 @@ OC.L10N.register(
     "Email" : "email",
     "Proceed" : "Nastavi",
     "Out of office" : "Van kancelarije",
-    "Unknown" : "Nepoznato",
     "Done" : "Gotovo",
+    "Unknown" : "Nepoznato",
     "never" : "never",
-    "Details" : "Detalji",
+    "Yes" : "Da",
+    "No" : "Ne",
+    "None" : "Ništa",
     "Close" : "Zatvori",
+    "Participants" : "Učesnici",
     "Daily" : "дневно",
     "Weekly" : "недељно",
     "second" : "sekund",
