@@ -125,7 +125,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Det gick inte att uppdatera kalenderordningen.",
     "Shared calendars" : "Delade kalendrar",
     "Deck" : "Deck",
-    "Hidden" : "Gömd",
     "Internal link" : "Intern länk",
     "A private link that can be used with external clients" : "En privat länk som kan användas med externa klienter",
     "Copy internal link" : "Kopiera intern länk",
@@ -153,7 +152,7 @@ OC.L10N.register(
     "Share with users or groups" : "Dela med användare eller grupper",
     "No users or groups" : "Inga användare eller grupper",
     "Failed to save calendar name and color" : "Det gick inte att spara kalendernamn och färg",
-    "Calendar name …" : "Kalendernamn ...",
+    "Calendar name …" : "Kalendernamn …",
     "Never show me as busy (set this calendar to transparent)" : "Visa mig aldrig som upptagen (ställ in den här kalendern på transparent)",
     "Share calendar" : "Dela kalender",
     "Unshare from me" : "Sluta dela från mig",
@@ -355,6 +354,7 @@ OC.L10N.register(
     "Legend" : "Etikett",
     "Out of office" : "Ej på plats",
     "Attendees:" : "Deltagare:",
+    "local time" : "lokal tid",
     "Done" : "Klar",
     "Search room" : "Sök rum",
     "Room name" : "Rumsnamn",
@@ -454,6 +454,7 @@ OC.L10N.register(
     "Yes" : "Ja",
     "No" : "Nej",
     "Maybe" : "Kanske",
+    "None" : "Ingen",
     "Select your meeting availability" : "Välj din tillgänglighet",
     "Create a meeting for this date and time" : "Skapa ett möte för detta datum och tid",
     "Create" : "Skapa",
@@ -506,6 +507,7 @@ OC.L10N.register(
     "Show unscheduled tasks" : "Visa ej schemalagda uppgifter",
     "Unscheduled tasks" : "Ej schemalagda uppgifter",
     "Availability of {displayName}" : "Tillgänglighet för {displayName}",
+    "Discard event" : "Avbryt händelse",
     "Edit event" : "Redigera händelse",
     "Event does not exist" : "Händelsen existerar inte",
     "Duplicate" : "Duplicera",
@@ -516,6 +518,8 @@ OC.L10N.register(
     "Managing shared access" : "Hantering av delad åtkomst",
     "Deny access" : "Neka åtkomst",
     "Invite" : "Bjud in",
+    "Discard changes?" : "Avbryt ändringar?",
+    "Are you sure you want to discard the changes made to this event?" : "Är du säker på att du vill avbryta ändringarna som gjorts i denna händelse?",
     "_User requires access to your file_::_Users require access to your file_" : ["En användare behöver tillgång till din fil","Användare behöver tillgång till din fil"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Bilaga i behov av delat åtkomst","Bilagor i behov av delad åtkomst"],
     "Untitled event" : "Namnlös händelse",
@@ -660,12 +664,15 @@ OC.L10N.register(
     "An error occurred during uploading file {fileName}" : "Ett fel uppstod vid uppladdning av filen {fileName}",
     "An error occurred during getting file information" : "Ett fel uppstod vid hämtning av filinformation",
     "Talk conversation for event" : "Talk-konversation för händelse",
+    "Talk conversation for proposal" : "Talk-konversation för förslaget",
     "An error occurred, unable to delete the calendar." : "Ett fel inträffade, kunde inte radera kalendern.",
     "Imported {filename}" : "Importerad {filename}",
     "This is an event reminder." : "Detta är en händelsepåminnelse.",
     "Error while parsing a PROPFIND error" : "Fel vid analys av ett PROPFIND-fel",
     "Appointment not found" : "Mötet hittades inte",
     "User not found" : "Användaren hittades inte",
+    "Hidden" : "Gömd",
+    "Calendar name …" : "Kalendernamn ...",
     "Automatic ({detected})" : "Automatisk ({detected})",
     "Shortcut overview" : "Översikt av genvägar",
     "Enable simplified editor" : "Aktivera förenklad redigerare",
